@@ -15,18 +15,14 @@ from retry import retry
 class CentralReachCore(SitesCore):
     def __init__(
         self,
-        login: str,
-        password: str,
-        auth_totp_key: str = "",
-        captcha_api_key: str | tuple[str, str] = "",
-        url: str = "https://members.centralreach.com/#login",
+        client_id: str,
+        client_secret: str,
+        url: str = "https://members.centralreach.com/#account",
         start_date: date = date.today().replace(day=1),
         end_date: date = date.today(),
         timeout: int = 30,
         temp_folder: str = "",
         headless: bool = False,
-        client_id: str = "",
-        client_secret: str = "",
     ):
         """
         CentralReachCore object. Please Inheritance it.
@@ -42,73 +38,12 @@ class CentralReachCore(SitesCore):
         :param timeout: timeout for action. The default value is 30 seconds.
         :param temp_folder: Path to temp folder. The default value is temp/cr.
         """
-        super().__init__(login, password, auth_totp_key, url, timeout, temp_folder, headless)
-        self.start_date: date = start_date
-        self.end_date: date = end_date
+        super().__init__("", "", "", url, timeout, temp_folder, headless)
         self.client_id = client_id
         self.client_secret = client_secret
-        self._do_auth = bool(self.client_id) and bool(self.client_secret)
-        if isinstance(captcha_api_key, str):
-            self.captcha_provider = "captcha.guru"
-            self.captcha_api_key = captcha_api_key
-        else:
-            self.captcha_provider = captcha_api_key[0]
-            self.captcha_api_key = captcha_api_key[1]
-
-    def _get_captcha_info(self):
-        """
-        Get all Google reCatpcha info. Obtains info for v2 and v3 captchas
-        """
-        data = self.browser.execute_javascript(
-            """
-        function findRecaptchaClients() {
-  // eslint-disable-next-line camelcase
-  if (typeof (___grecaptcha_cfg) !== 'undefined') {
-    // eslint-disable-next-line camelcase, no-undef
-    return Object.entries(___grecaptcha_cfg.clients).map(([cid, client]) => {
-      const data = { id: cid, version: cid >= 10000 ? 'V3' : 'V2' };
-      const objects = Object.entries(client).filter(([_, value]) => value && typeof value === 'object');
-
-      objects.forEach(([toplevelKey, toplevel]) => {
-        const found = Object.entries(toplevel).find(([_, value]) => (
-          value && typeof value === 'object' && 'sitekey' in value && 'size' in value
-        ));
-
-        if (typeof toplevel === 'object' && toplevel instanceof HTMLElement && toplevel['tagName'] === 'DIV'){
-            data.pageurl = toplevel.baseURI;
-        }
-
-        if (found) {
-          const [sublevelKey, sublevel] = found;
-
-          data.sitekey = sublevel.sitekey;
-          const callbackKey = data.version === 'V2' ? 'callback' : 'promise-callback';
-          const callback = sublevel[callbackKey];
-          if (!callback) {
-            data.callback = null;
-            data.function = null;
-          } else {
-            data.function = callback;
-            const keys = [cid, toplevelKey, sublevelKey, callbackKey].map((key) => `['${key}']`).join('');
-            data.callback = `___grecaptcha_cfg.clients${keys}`;
-          }
-        }
-      });
-      return data;
-    });
-  }
-  return [];
-}
-
-let res = findRecaptchaClients();
-return res
-        """
-        )
-        logging.info(data)
-        self.key = data[0]["sitekey"]
-        self.page_url = data[0]["pageurl"]
-        self.function = data[0]["function"]
-        self.callback = data[0]["callback"]
+        self.start_date: date = start_date
+        self.end_date: date = end_date
+        self.request_session = requests.sessions.Session()
 
     def _get_auth_token(self, client_id, client_secret):
         """Retrieve the authentication token."""
@@ -119,12 +54,10 @@ return res
             "scope": "cr-api",
         }
 
-        return requests.post("https://login.centralreach.com/connect/token", data=data)
+        return self.request_session.post("https://login.centralreach.com/connect/token", data=data)
 
     def _get_internal_cookie(self, jwt):
         """Exchange the authentication token for an internal session cookie."""
-        import requests
-
         headers = {
             "Accept": "application/json",
         }
@@ -133,21 +66,12 @@ return res
             "token": jwt["access_token"],
         }
 
-        return requests.post(
+        return self.request_session.post(
             "https://members.centralreach.com/api/?framework.authtoken", headers=headers, json=json_data
         )
 
+    @retry(tries=3, delay=5)
     def login_to_site(self) -> bool:
-        """
-        Try login to the site.
-
-        :return: Status of the login. True if successfully log in
-        """
-        username_field = '//*[@id="Username"]'
-        next_btn = '//*[@id="login"]'
-        password_field = '//*[@id="Password"]'
-
-        self.is_site_available = False
         self.browser.close_browser()
 
         if self.temp_folder:
@@ -156,128 +80,35 @@ return res
             os.mkdir(self.temp_folder)
             self.browser.set_download_directory(self.temp_folder, True)
 
-        for i in range(1, 4):
-            try:
-                self.browser.open_chrome_browser(self.url, headless=self._headless)
+        _ = self._get_internal_cookie(self._get_auth_token(self.client_id, self.client_secret).json())
+        self.browser.open_chrome_browser(self.url, headless=self._headless)
 
-                # get API auth cookies for RPA automation
-                if self._do_auth:
-                    new_cookies = self._get_internal_cookie(
-                        self._get_auth_token(self.client_id, self.client_secret).json()
-                    )
+        for cookie in self.request_session.cookies:
+            selenium_cookie = {
+                "name": cookie.name,
+                "value": cookie.value,
+                "domain": cookie.domain,
+                "path": cookie.path,
+                "secure": cookie.secure,
+                "httpOnly": cookie.has_nonstandard_attr("HttpOnly"),
+            }
+            if cookie.expires:
+                selenium_cookie["expiry"] = int(cookie.expires)
+            self.browser.driver.add_cookie(selenium_cookie)
 
-                    for cookie_name, cookie_value in new_cookies.cookies.get_dict().items():
-                        self.browser.add_cookie(str(cookie_name), str(cookie_value))
-
-                self.browser.set_window_size(1920, 1080)
-                self.wait_element(username_field, is_need_screenshot=False, timeout=10)
-
-                self.check_scheduled_maintenance()
-
-                self.wait_element(username_field)
-                self.browser.input_text_when_element_is_visible(username_field, self.login)
-                self.browser.click_button_when_visible(next_btn)
-
-                self.wait_element(password_field)
-                self.browser.input_text_when_element_is_visible(password_field, self.password)
-
-                for attempt in range(1, 4):
-                    try:
-                        # Take screenshot before attempting captcha
-                        self.browser.capture_page_screenshot(
-                            os.path.join(self.output_folder, f"captcha_attempt_{attempt}_before.png")
-                        )
-                        logging.info(f"Starting captcha attempt {attempt}")
-                        logging.info("Getting captcha info")
-                        self._get_captcha_info()
-                        from twocaptcha import TwoCaptcha
-
-                        logging.info("Solving captcha with 2captcha")
-                        solver = TwoCaptcha(self.captcha_api_key)
-                        result = solver.recaptcha(
-                            sitekey=self.key, url=self.browser.get_location(), invisible=True, enterprise=1
-                        )
-                        code = result["code"]
-                        logging.info(f"Captcha code: {code}")
-                        logging.info("Injecting captcha code")
-                        self.browser.execute_javascript(
-                            "document.getElementById('g-recaptcha-response').innerHTML='{}'".format(code)
-                        )
-                        logging.info("Injecting captcha callback")
-                        self.browser.execute_javascript(self.callback + f"('{code}')")
-                        logging.info("Clicking next button")
-                        self.browser.click_button_when_visible(next_btn)
-                        validation_error = "//li[contains(text(), 'Recaptcha validation failed')]"
-                        if self.browser.does_page_contain_element(validation_error):
-                            logging.error("Captcha validation failed")
-                            self.browser.go_to("https://login.centralreach.com")
-                            raise Exception("Captcha validation failed")
-                        logging.info("Successfully Bypassed Captcha")
-
-                        # Take screenshot after successful captcha
-                        self.browser.capture_page_screenshot(
-                            os.path.join(self.output_folder, f"captcha_attempt_{attempt}_success.png")
-                        )
-                        break
-                    except KeyboardInterrupt:
-                        # Re-raise keyboard interrupt immediately
-                        raise
-                    except SystemExit:
-                        # Re-raise system exit immediately
-                        raise
-                    except BaseException as ex:
-                        # Catch all exceptions including those that don't inherit from Exception
-                        # Take screenshot after captcha failure
-                        self.browser.capture_page_screenshot(
-                            os.path.join(self.output_folder, f"captcha_attempt_{attempt}_failed.png")
-                        )
-
-                        logging.error(f"Failed to Bypass Captcha Attempt: {attempt}")
-                        logging.error(f"Exception type: {type(ex).__name__}")
-                        logging.error(f"Exception message: {str(ex)}")
-                        if attempt == 3:
-                            logging.info("Final captcha attempt failed, clicking button anyway")
-                            self.browser.click_button_when_visible(next_btn)
-                            break
-                        # Add a small delay between captcha attempts
-                        logging.info(f"Waiting 2 seconds before captcha attempt {attempt + 1}")
-                        time.sleep(2)
-                        continue
-
-                self.is_password_expired = self.check_password_expired()
-                if self.is_password_expired:
-                    break
-
-                if self.browser.does_page_contain_element(
-                    '//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]'  # noqa
-                ):
-                    elem = self.browser.find_element(
-                        '//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]'  # noqa
-                    )
-                    if elem.is_displayed():
-                        logging.warning("Logging into CentralReach failed. There was an unexpected problem signing in.")
-                        raise CentralReachException(
-                            "Unexpected error during signing in. If you keep seeing this, contact CentralReach Support"
-                        )
-
-                self.pass_mfa()
-                self.wait_element_and_refresh('//span[text()="Favorites"]', is_need_screenshot=False)
-
-                if self.does_element_displayed('//span[text()="Continue To Login"]'):
-                    self.click('//span[text()="Continue To Login"]')
-
-                self.is_site_available = self.browser.does_page_contain_element('//span[text()="Favorites"]')
-                self.base_url: str = self.get_base_url(self.browser.get_location())
-
-                return self.is_site_available
-            except ScheduledMaintenance as ex:
-                raise ex
-            except Exception as ex:
-                logging.error(f"Logging into CentralReach. Attempt #{i} failed")
-                logging.error(str(ex))
-                self.browser.capture_page_screenshot(os.path.join(self.output_folder, f"Login_failed_Attempt_{i}.png"))
-                self.browser.close_browser()
-        return False
+        self.browser.go_to(self.url)
+        time.sleep(10)
+        self.browser.set_window_size(1920, 1080)
+        self.check_scheduled_maintenance()
+        if self.does_element_displayed('//span[text()="Continue To Login"]'):
+            self.click('//span[text()="Continue To Login"]')
+        if self.does_element_displayed('//button[@data-testid="bulk-update-status-cancel"]'):
+            self.click('//button[@data-testid="bulk-update-status-cancel"]')
+        if not self.browser.does_page_contain_element('//span[contains(text(), "Dashboard")]'):
+            logging.error("Couldn't properly verify that the worker is logged into CentralReach.")
+            self.browser.capture_page_screenshot(os.path.join(self.output_folder, "CentralReach_login_failed.png"))
+            raise Exception("Couldn't properly login to CentralReach")
+        self.base_url: str = self.get_base_url(self.browser.get_location())
 
     def wait_element(self, xpath: str, timeout: int = 60, is_need_screenshot: bool = True) -> bool:
         """
