@@ -44,3 +44,11 @@ class EmptyPageError(EmptyPage, CentralReachError):
 
 class BadRequestError(BadRequest, CentralReachError):
     pass
+
+
+class PasswordExpiredException(CentralReachException):
+    """
+    This exception is raised when a password is expired
+    """
+
+    pass
