@@ -1,12 +1,8 @@
 import datetime
 import json
-import time
 import requests
 from retry import retry
-from .exceptions import BadRequestError, ScheduledMaintenanceError, PasswordExpiredException
-from .core import CentralReachCore
-import logging
-import os
+from .exceptions import BadRequestError, ScheduledMaintenanceError
 
 
 def retry_if_bad_request(func):
@@ -29,13 +25,8 @@ def retry_if_bad_request(func):
 class CentralReachRequestsCore:
     def __init__(
         self,
-        login: str,
-        password: str,
-        auth_totp_key: str = "",
-        captcha_api_key: str | tuple[str, str] = "",
-        bw_creds: dict = None,
-        client_id: str = "",
-        client_secret: str = "",
+        client_id: str,
+        client_secret: str,
     ):
         """
         CentralReachRequestsCore object. Please Inheritance it.
@@ -44,31 +35,20 @@ class CentralReachRequestsCore:
         :param password: password for CentralReach site.
         :param captcha_api_key: api_key for captcha solver - can be just api_key itself or (provider, api_key) tuple.
         """
-        self.__login = login
-        self.__password = password
-        self.__auth_totp_key = auth_totp_key
-        self.__captcha_api_key = captcha_api_key
-        self.__client_id = client_id
-        self.__client_secret = client_secret
-        self._session_csrf_token = ""
-        self.session = requests.session()
-        self._login_to_central_reach()
+        self.session = requests.sessions.Session()
+        _ = self._get_internal_cookie(self._get_auth_token(client_id, client_secret).json())
 
-    def _get_headers(self, is_json=True, add_headers: dict = None, put_token: bool = True) -> dict:
+    def _get_headers(self, is_json=True, add_headers: dict = None) -> dict:
         """
         Prepare header object for request.
 
         :param is_json (bool): True if content-type should be json, else False.
-        :param add_headers (dict): dictionary with key-values that should be added to headers.
-        :param put_token (bool): True if 'csrf-token' should be added to headers, else False.
+        :param add_headers (dict): dictionary with key-values that should be added to headers..
         """
         headers = {"origin": "https://members.centralreach.com"}
         if is_json:
             headers["content-type"] = "application/json; charset=UTF-8"
 
-        if put_token:
-            headers["x-csrf-token"] = self._session_csrf_token
-
         if add_headers:
             for key, value in add_headers.items():
                 headers[key] = value
@@ -135,82 +115,30 @@ class CentralReachRequestsCore:
                     f"{exc_message}Status Code: {response.status_code}, " f"Headers: {response.headers}"
                 )
 
-    @retry_if_bad_request
-    def _login_to_central_reach(self) -> None:
-        self.central_reach_core = CentralReachCore(
-            self.__login,
-            self.__password,
-            self.__auth_totp_key,
-            self.__captcha_api_key,
-            headless=True,
-            client_id=self.__client_id,
-            client_secret=self.__client_secret,
+    def _get_auth_token(self, client_id, client_secret):
+        """Retrieve the authentication token."""
+        data = {
+            "grant_type": "client_credentials",
+            "client_id": client_id,
+            "client_secret": client_secret,
+            "scope": "cr-api",
+        }
+
+        return self.session.post("https://login.centralreach.com/connect/token", data=data)
+
+    def _get_internal_cookie(self, jwt):
+        """Exchange the authentication token for an internal session cookie."""
+        headers = {
+            "Accept": "application/json",
+        }
+
+        json_data = {
+            "token": jwt["access_token"],
+        }
+
+        return self.session.post(
+            "https://members.centralreach.com/api/?framework.authtoken", headers=headers, json=json_data
         )
-        self.central_reach_core.login_to_site()
-        self.session = requests.session()
-
-        password_expired = self.central_reach_core.is_password_expired
-        if password_expired:
-            raise PasswordExpiredException("Please reset AI worker password for Central Reach")
-
-        # Check authorisation
-        logging.info("Starting session authorization process...")
-        self.central_reach_core.browser.capture_page_screenshot(
-            os.path.join(self.central_reach_core.output_folder, "session_auth_start.png")
-        )
-
-        timeout_time = datetime.datetime.now() + datetime.timedelta(seconds=30)
-        while datetime.datetime.now() < timeout_time:
-            try:
-                # Set cookies
-                logging.info("Copying browser cookies to session...")
-                browser_cookies = self.central_reach_core.browser.get_cookies(as_dict=True)
-                logging.info(f"Found {len(browser_cookies)} browser cookies")
-
-                for name, value in browser_cookies.items():
-                    self.session.cookies.set(name, value)
-
-                # Save csrf-token
-                try:
-                    self._session_csrf_token = self.session.cookies["csrf-token"]
-                    logging.info("csrf-token found and saved")
-                except KeyError:
-                    logging.error("csrf-token cookie missing from session")
-                    logging.error(f"Available cookies: {list(self.session.cookies.keys())}")
-                    # Screenshot when csrf-token is missing
-                    self.central_reach_core.browser.capture_page_screenshot(
-                        os.path.join(self.central_reach_core.output_folder, "session_auth_missing_csrf_token.png")
-                    )
-                    raise BadRequestError(
-                        "Session doesn't contain the required cookie 'csrf-token' after logging " "into Central Reach"
-                    )
-
-                # Check authorization
-                logging.info("Testing API authorization...")
-                self.__insurance_eligibility_status()
-                logging.info("API authorization successful!")
-                # Screenshot on success
-                self.central_reach_core.browser.capture_page_screenshot(
-                    os.path.join(self.central_reach_core.output_folder, "session_auth_success.png")
-                )
-                break
-            except BadRequestError as e:
-                logging.warning(f"Authorization check failed: {e}")
-                # Screenshot on each authorization failure
-                timestamp = datetime.datetime.now().strftime("%H%M%S")
-                self.central_reach_core.browser.capture_page_screenshot(
-                    os.path.join(self.central_reach_core.output_folder, f"session_auth_failed_{timestamp}.png")
-                )
-                time.sleep(1)
-                continue
-        else:
-            # Screenshot before final failure
-            self.central_reach_core.browser.capture_page_screenshot(
-                os.path.join(self.central_reach_core.output_folder, "session_auth_final_failure.png")
-            )
-            self.central_reach_core.browser.close_browser()
-            raise BadRequestError("Session is unauthorized after login to Central Reach")
-        self.central_reach_core.browser.close_browser()
 
     def __insurance_eligibility_status(self) -> None:
         header = {"referer": "https://members.centralreach.com/"}
