@@ -43,7 +43,7 @@ class QuickbooksCore(SitesCore):
             try:
                 self.browser.open_chrome_browser(self.url)
                 self.browser.set_window_size(1920, 1080)
-                self.browser.maximize_browser_window()
+                # self.browser.maximize_browser_window()
 
                 self.wait_element('//input[@id="ius-signin-userId-input"]', timeout=30, is_need_screenshot=False)
                 if self.does_element_displayed('//input[@id="ius-signin-userId-input"]'):
