@@ -6,8 +6,9 @@ from threading import Event, Thread
 import requests
 from RPA.Browser.Playwright import Playwright
 from retry import retry
+from fake_useragent import UserAgent
 
-from .exceptions import VersantError, BadRequestError, WrongPasswordError, WrongCredentialsError, BrowserError
+from .exceptions import VersantError, BadRequestError, WrongCredentialsError, BrowserError
 
 
 def retry_if_bad_request(func):
@@ -36,6 +37,8 @@ class VersantRequestsCore:
         :param password: password for CentralReach site.
         """
         self.session = requests.session()
+        # usable user-agent
+        self.user_agent = UserAgent().chrome
         # Login data
         self.__login = login
         self.__password = password
@@ -63,10 +66,7 @@ class VersantRequestsCore:
         browser = Playwright()
         browser.set_browser_timeout(timedelta(seconds=100))
         browser.new_browser(SupportedBrowsers.chromium, headless=open_as_headless, timeout=timedelta(seconds=120))
-        browser.new_context(
-            userAgent="Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) "
-            "Chrome/51.0.2704.103 Safari/537.36",
-        )
+        browser.new_context(userAgent=UserAgent().chrome)
         browser.new_page()
         return browser
 
@@ -137,8 +137,10 @@ class VersantRequestsCore:
         browser = None
         try:
             try:
+                from Browser.utils.data_types import PageLoadStates
+
                 browser = self.__setup_browser()
-                browser.go_to(url)
+                browser.go_to(url=url, timeout=timedelta(seconds=180), wait_until=PageLoadStates.domcontentloaded)
 
                 browser.wait_for_elements_state('//*[@id="username"]', timeout=timedelta(seconds=120))
                 browser.fill_text('//*[@id="username"]', login)
@@ -160,28 +162,22 @@ class VersantRequestsCore:
 
                 time.sleep(1)
                 browser.click('//button[@class="btn btn-light submit-button"]')  # Click of the Login button
-                event.wait()  # Wait while response is ready
+                is_event_succ = event.wait(600.0)  # Wait while response is ready
+
+                if not is_event_succ:
+                    raise BrowserError("Timeout of 600 seconds reached on login.")
+
             except Exception as ex:
-                raise BrowserError(f"Can't login to Versant. Exception: {ex}")
+                raise BrowserError(f"Can't login to Versant. Exception: {ex}") from ex
 
             response_body = response["body"]["body"]
-            if response_body["statuscode"] != 200:
+            if response_body["statuscode"] != "OK":
                 if response_body["messages"]:
                     error_message: dict = response_body["messages"][0]
-                    if error_message["code"] == "12.01.09" or "attempt" in error_message["description"]:
-                        raise WrongPasswordError(
-                            "The password for Versant is incorrect, "
-                            "be careful because after several attempts the account may be blocked."
-                            f" (Response details: Status code {response_body['statuscode']}, "
-                            f"Error code {error_message['code']}, "
-                            f"Description {error_message['description']})"
-                        )
-                    elif error_message["code"] == "12.01.10" or "Invalid grant." in error_message["description"]:
+                    if error_message["code"] == "11.01.05":
                         raise WrongCredentialsError(
-                            "The credentials for Versant is incorrect."
-                            f" (Response details: Status code {response_body['statuscode']}, "
-                            f"Error code {error_message['code']}, "
-                            f"Description {error_message['description']})"
+                            "Versant login attempt failed due to incorrect credentials. "
+                            f"Details: {error_message['description']}"
                         )
                 raise VersantError("Can't login to Versant")
 
